TestGenConfig

Struct TestGenConfig 

pub struct TestGenConfig {
    pub unit_tests_per_function: usize,
    pub property_tests_per_function: usize,
    pub property_test_cases: usize,
    pub generate_doc_tests: bool,
    pub generate_mutation_config: bool,
    pub behavior_equivalence_tests: bool,
}
Configuration for test generation.

Fields

unit_tests_per_function: usize

Number of unit tests to generate per function (default: 5)

property_tests_per_function: usize

Number of property tests to generate per function (default: 5)

property_test_cases: usize

Number of test cases for each property test (default: 1000)

generate_doc_tests: bool

Whether to generate doc tests (default: true)

generate_mutation_config: bool

Whether to generate mutation test configuration (default: true)

behavior_equivalence_tests: bool

Whether to generate behavior equivalence tests (default: true if C available)